@@ -92,9 +92,10 @@ def data(varName='', varContent='', codeContent=''):
 
     varContent = colored(str(varContent), 'yellow')
 
-    codeContent = colored(str(codeContent), 'grey')
+    if not codeContent == '':
+        codeContent = ' (' + colored(str(codeContent) + ')', 'grey')
 
-    output = varName + ' = ' + varContent + ' (' + codeContent + ')'
+    output = varName + ' = ' + varContent + codeContent
 
     return(prefixer('DataPrint', output))
 
